from nimbella.storage.plugins.gcs_storage_plugin import GoogleCloudStoragePlugin, GoogleCloudStorageFile

import unittest
from unittest.mock import MagicMock
from unittest.mock import patch, mock_open

from google.cloud.storage.blob import Blob

class TestGoogleCloudStoragePlugin(unittest.TestCase):
    def test_google_storage_plugin_id(self):
        id = "@nimbella/storage-gcs"
        self.assertEqual(GoogleCloudStoragePlugin.id(), id)

    def test_constructor(self):
        client = MagicMock()
        gcs = GoogleCloudStoragePlugin(client, '', '', '', '')
        client.get_bucket.assert_called_with(gcs.bucket_key)

    def test_bucket_key_property(self):
        client = MagicMock()
        namespace = 'this-is-a-namespace'
        apiHost = 'https://this.is.a.host.com'

        # test bucket keys for web buckets
        web = True
        gcs = GoogleCloudStoragePlugin(client, namespace, apiHost, web, '')
        self.assertEqual(gcs.bucket_key, f'{namespace}-this-is-a-host-com')

        # test bucket keys for data buckets
        gcs.web = False
        self.assertEqual(gcs.bucket_key, f'data-{namespace}-this-is-a-host-com')

    def test_bucket_url(self):
        client = MagicMock()
        namespace = 'this-is-a-namespace'
        apiHost = 'https://this.is.a.host.com'

        gcs = GoogleCloudStoragePlugin(client, namespace, apiHost, True, '')
        self.assertEqual(gcs.url, f'https://{namespace}-this-is-a-host-com')

        # Data storage buckets should not return a URL
        gcs.web = False
        self.assertEqual(gcs.url, None)

    def test_bucket_delete_files(self):
        prefix = 'folder/'
        blobs = [
            Blob(name='folder/a-file', bucket='some-bucket'),
            Blob(name='folder/b-file', bucket='some-bucket'),
            Blob(name='folder/c-file', bucket='some-bucket')
        ]
        client = MagicMock()
        client.list_blobs = MagicMock(return_value=iter(blobs))

        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        gcs.bucket.delete_blobs = MagicMock()

        gcs.deleteFiles(prefix)

        client.list_blobs.assert_called_with(gcs.bucket, prefix=prefix)
        gcs.bucket.delete_blobs.assert_called_with(blobs)

    def test_bucket_get_files(self):
        client = MagicMock()
        blobs = [
            Blob(name='folder/a-file', bucket='some-bucket'),
            Blob(name='folder/b-file', bucket='some-bucket'),
            Blob(name='folder/c-file', bucket='some-bucket')
        ]
        client.list_blobs = MagicMock(return_value=iter(blobs))
        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        prefix = 'folder/'
        files = list(gcs.getFiles(prefix))
        file_blobs = list(map(lambda f: f.blob, files))
        self.assertEqual(file_blobs, blobs)
        client.list_blobs.assert_called_with(gcs.bucket, prefix=prefix)

    def test_bucket_get_file(self):
        client = MagicMock()
        destination = 'folder/file.txt'
        blob = Blob(name=destination, bucket='some-bucket')
        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        gcs.bucket.blob = MagicMock(return_value=blob)
        self.assertEqual(gcs.file(destination).blob, blob)
        gcs.bucket.blob.assert_called_with(destination)

    def test_bucket_set_website(self):
        client = MagicMock()
        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        mainPageSuffix = "index.html"
        notFoundPage = "404.html"
        gcs.bucket.configure_website = MagicMock()
        gcs.setWebsite(mainPageSuffix, notFoundPage)
        gcs.bucket.configure_website.assert_called_with(mainPageSuffix, notFoundPage)

    @patch("builtins.open", new_callable=mock_open, read_data="data")
    def test_bucket_upload(self, mock_file):
        client = MagicMock()
        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        path = '/file/path.txt'
        destination = 'folder/path.txt'
        contentType = 'text/plain'
        cacheControl = 'no-cache'

        blob = Blob(name=destination, bucket='some-bucket')
        gcs = GoogleCloudStoragePlugin(client, '', '', True, '')
        gcs.bucket.blob = MagicMock(return_value=blob)
        blob.upload_from_file = MagicMock()
        gcs.upload(path, destination, contentType, cacheControl)
        gcs.bucket.blob.assert_called_with(destination)
        blob.upload_from_file.assert_called_with(file_obj=mock_file(path, 'rb'), content_type=contentType)
        mock_file.assert_called_with(path, 'rb')





from nimbella.storage.plugins.aws_storage_plugin import AWSStoragePlugin, S3StorageFile


import unittest
from unittest.mock import MagicMock
from unittest.mock import patch, mock_open
from types import SimpleNamespace

class TestAWSStoragePlugin(unittest.TestCase):
    def test_aws_storage_plugin_id(self):
        id = "@nimbella/storage-s3"
        self.assertEqual(AWSStoragePlugin.id(), id)

    def test_constructor(self):
        client = MagicMock()
        client.resource = MagicMock(return_value=MagicMock())
        aws = AWSStoragePlugin(client, '', '', '', '')
        client.resource().Bucket.assert_called_with(aws.bucket_key)

    def test_bucket_key_property(self):
        client = MagicMock()
        namespace = 'this-is-a-namespace'
        apiHost = 'https://this.is.a.host.com'

        # test bucket keys for web buckets
        web = True
        aws = AWSStoragePlugin(client, namespace, apiHost, web, '')
        self.assertEqual(aws.bucket_key, f'{namespace}-nimbella-io')

        # test bucket keys for data buckets
        aws.web = False
        self.assertEqual(aws.bucket_key, f'data-{namespace}-nimbella-io')

    def test_bucket_url(self):
        # test happy path using bucket location in creds
        client = MagicMock()
        namespace = 'this-is-a-namespace'
        apiHost = 'https://this.is.a.host.com'
        bucketHost = 'bucket.host.com'
        credentials = {
            "endpoint": f'https://{bucketHost}' 
        }

        aws = AWSStoragePlugin(client, namespace, apiHost, True, credentials)
        self.assertEqual(aws.url, f'http://{namespace}-nimbella-io.{bucketHost}')

        # Test bucket credentials contain weburl
        weburl = "http://some_other_address.com"
        aws.credentials["weburl"] = weburl
        self.assertEqual(aws.url, weburl)

        # Data storage buckets should not return a URL
        aws.web = False
        self.assertEqual(aws.url, None)

    def test_bucket_delete_files(self):
        prefix = "folder/"
        files = [
            SimpleNamespace(key="folder/a-file"),
            SimpleNamespace(key="folder/b-file"),
            SimpleNamespace(key="folder/c-file"),
        ]
        keys = list(map(lambda f: f.key, files))

        client = MagicMock()

        aws = AWSStoragePlugin(client, '', '', True, '')
        aws.bucket.delete_objects = MagicMock()
        aws.bucket.objects.filter = MagicMock(return_value=files)
        aws.bucket.Object = MagicMock(side_effect=lambda key: SimpleNamespace(key=key))

        aws.deleteFiles(prefix)

        aws.bucket.delete_objects.assert_called_with(Delete={
            "Objects": list(map(lambda o: {"Key": o.key}, files))
        })
        aws.bucket.objects.filter.assert_called_with(Prefix=prefix)

    def test_bucket_get_files(self):
        client = MagicMock()
        prefix = "folder/"
        files = [
            SimpleNamespace(key="folder/a-file"),
            SimpleNamespace(key="folder/b-file"),
            SimpleNamespace(key="folder/c-file"),
        ]
        keys = list(map(lambda f: f.key, files))
        aws = AWSStoragePlugin(client, '', '', True, '')

        aws.bucket.objects.filter = MagicMock(return_value=files)
        aws.bucket.Object = MagicMock(side_effect=lambda key: SimpleNamespace(key=key))

        files = aws.getFiles(prefix)
        files_keys = list(map(lambda f: f.name, files))
        self.assertEqual(files_keys, keys)
        aws.bucket.objects.filter.assert_called_with(Prefix=prefix)

    def test_bucket_get_file(self):
        client = MagicMock()
        destination = 'folder/file.txt'
        obj = SimpleNamespace(key=destination)
        aws = AWSStoragePlugin(client, '', '', True, '')
        aws.bucket.Object = MagicMock(return_value=obj)

        self.assertEqual(aws.file(destination).name, destination)
        aws.bucket.Object.assert_called_with(destination)

    def test_bucket_set_website(self):
        client = MagicMock()
        aws = AWSStoragePlugin(client, '', '', True, '')
        mainPageSuffix = "index.html"
        notFoundPage = "404.html"
        website = MagicMock()
        aws.bucket.Website = MagicMock(return_value = website)
        WebsiteConfiguration = {
            'ErrorDocument': {'Key': notFoundPage},
            'IndexDocument': {'Suffix': mainPageSuffix},
        }
        aws.setWebsite(mainPageSuffix, notFoundPage)
        website.put.assert_called_with(WebsiteConfiguration=WebsiteConfiguration)

    def test_bucket_upload(self):
        client = MagicMock()
        aws = AWSStoragePlugin(client, '', '', True, '')
        path = '/file/path.txt'
        destination = 'folder/path.txt'
        contentType = 'text/plain'
        cacheControl = 'no-cache'
        extraArgs = {
            "ContentType": contentType,
            "CacheControl": cacheControl
        }

        aws.bucket.upload_file = MagicMock()

        aws.upload(path, destination, contentType, cacheControl)
        aws.bucket.upload_file.assert_called_with(path, destination, ExtraArgs=extraArgs)



from .abstract_storage_plugin import AbstractStoragePlugin, AbstractStorageFile

from typing import Union
from urllib.parse import urlparse

import boto3
import botocore

# Simple wrapper around AWS S3 Object class to provide
# generic "storage file" for this provider
class S3StorageFile(AbstractStorageFile):
    def __init__(self, file, web, client):
        self.file = file
        self.web = web
        self.client = client

    @property
    def acl(self) -> str:
        return 'public-read' if self.web else ''

    @property
    def name(self) -> str:
        return self.file.key

    @property
    def metadata(self) -> dict:
        if self.exists():
            return self.file.metadata
        else:
            return {}

    @metadata.setter
    def metadata(self, metadata: dict):
        self.file.copy_from(CopySource={'Bucket':self.file.bucket_name, 'Key':self.file.key}, Metadata=metadata, MetadataDirective='REPLACE', ACL=self.acl)

    # This is convoluted but AWS SDK does not have a simple
    # exists() method, see: https://stackoverflow.com/questions/33842944
    def exists(self) -> bool:
        try:
            self.file.load()
        except botocore.exceptions.ClientError as e:
            if e.response['Error']['Code'] == "404":
                return False
            else:
                raise
        else:
            return True

    def delete(self) -> None:
        self.file.delete()

    def save(self, data: Union[str, bytes], contentType: str) -> None:
        body = bytes(data, 'utf-8') if isinstance(data, str) else data
        self.file.put(Body=data, ContentType=contentType, ACL=self.acl)

    def download(self) -> bytes:
        response = self.file.get()
        return response['Body'].read()

    def signed_url(self, version: str, action: str, expires: int, contentType: str) -> str:
        method = f'{action.lower()}_object'
        params = {
            "Bucket": self.file.Bucket().name,
            "Key": self.name,
            "ResponseContentType": contentType
        }
        return self.client.generate_presigned_url(method, Params=params, ExpiresIn=expires)

# Simple wrapper around GoogleCloudStorage bucket class to provide
# generic bucket storage service for this provider
class AWSStoragePlugin(AbstractStoragePlugin):
    def __init__(self, client, namespace, apiHost, web, credentials):
        super().__init__(client, namespace, apiHost, web, credentials)
        self.bucket = self.client.resource('s3').Bucket(self.bucket_key)

    @staticmethod
    def id() -> str:
        return "@nimbella/storage-s3"

    @staticmethod
    def prepare_creds(credentials: dict) -> dict:
        return credentials['credentials']

    @staticmethod
    def create_client(credentials: dict) ->  botocore.client.BaseClient:
        session = boto3.Session(
            aws_access_key_id=credentials['accessKeyId'],
            aws_secret_access_key=credentials['secretAccessKey'])
        return session

    @property
    def url(self) -> Union[str, None]:
        if self.web:
            if "weburl" in self.credentials:
                return self.credentials["weburl"]
            else:
                hostname = urlparse(self.credentials["endpoint"]).netloc
                return f"http://{self.namespace}-nimbella-io.{hostname}"

    def file(self, destination) -> S3StorageFile:
        return S3StorageFile(self.bucket.Object(destination), self.web, self.client.client('s3'))

    def deleteFiles(self, prefix='') -> None:
        objects = self.bucket.objects.filter(Prefix=prefix)
        keys = list(map(lambda o: {"Key": o.key}, objects))
        if keys:
            self.bucket.delete_objects(Delete={ "Objects": keys })

    def upload(self, path, destination, contentType, cacheControl):
        extraArgs = {
            "ContentType": contentType,
            "CacheControl": cacheControl
        }
        self.bucket.upload_file(path, destination, ExtraArgs=extraArgs)

    def setWebsite(self, mainPageSuffix = None, notFoundPage = None):
        bucket_website = self.bucket.Website()
        website_configuration = {
            'ErrorDocument': {'Key': notFoundPage},
            'IndexDocument': {'Suffix': mainPageSuffix},
        }
        bucket_website.put(WebsiteConfiguration=website_configuration)

    def getFiles(self, prefix = '') -> list:
        objects = self.bucket.objects.filter(Prefix=prefix)
        return list(map(lambda o: S3StorageFile(self.bucket.Object(o.key), self.web, self.client.client('s3')), objects))

    @property
    def bucket_key(self):
        datapart = "" if self.web else "data-"
        return f"{datapart}{self.namespace}-nimbella-io"



from .plugins.abstract_storage_plugin import AbstractStoragePlugin
import sys
import logging
import importlib
from importlib import resources

# Plugin lookup table: Plugin Provider Id -> Plugin Class
PLUGINS = {}

# Return plugin class from provider identifier.
# Loads all local plugins before searching for provider plugin.
def find_plugin(id):
    if not PLUGINS:
        import_plugins()
        register_plugins()

    logging.debug(f'Looking for plugin from identifier: {id}')
    return PLUGINS.get(id)

# Find & import all potential Python plugins under the storage/plugins directory 
def import_plugins(package = "nimbella.storage.plugins"):
    files = resources.contents(package)
    plugins = [f[:-3] for f in files if f.endswith(".py") and f[0] != "_"]
    logging.debug(f'Discovered files in the {package} directory: {plugins}')
    for plugin in plugins:
        importlib.import_module(f"{package}.{plugin}")
        logging.debug(f'Importing potential plugin file: {package}.{plugin}')

# Use registered sub-classes of the abstract plugin class
# to build lookup table from plugin ids to classes.
def register_plugins():
    for sc in AbstractStoragePlugin.__subclasses__():
        plugin_name = sc.id()
        logging.debug(f'Found plugin with provider id: {plugin_name}')
        PLUGINS[plugin_name] = sc



import abc
import typing
from typing import Union

# Abstract Bucket File Interface.
# Hides provider implementation bucket file class instances
class AbstractStorageFile(abc.ABC):
    # Name of the bucket file
    @property
    @abc.abstractmethod
    def name(self) -> str:
        pass

    # key/value pairs for provider-specific object metadata
    @property
    @abc.abstractmethod
    def metadata(self) -> dict:
        pass

    @metadata.setter
    @abc.abstractmethod
    def metadata(self, metadata: dict):
        pass

    # does file exist?
    @abc.abstractmethod
    def exists(self) -> bool:
        pass

    # delete file from bucket
    @abc.abstractmethod
    def delete(self) -> None:
        pass

    # update file contents from string or bytes with content-type
    @abc.abstractmethod
    def save(self, data: Union[str, bytes], contentType: str) -> None:
        pass

    # return file contents as bytes
    @abc.abstractmethod
    def download(self) -> bytes:
        pass

    # return pre-signed url from file for external access
    @abc.abstractmethod
    def signed_url(self, version: str, action: str, expires: int, contentType: str) -> str:
        pass

# Abstract interface for a storage provider.
class AbstractStoragePlugin(abc.ABC):
    def __init__(self, client, namespace, apiHost, web, credentials):
        self.client = client
        self.namespace = namespace
        self.apiHost = apiHost
        self.web = web
        self.credentials = credentials
        pass

    # Static method used to access provider identifier without 
    # having to create a new class instance.
    @staticmethod
    @abc.abstractmethod
    def id():
        pass

    # Provider-specific method to convert JSON creds from platform
    # into credentials ready for passing into constructor.
    @staticmethod
    @abc.abstractmethod
    def prepare_creds():
        pass

    # Provider-specific method to create new provider storage
    # client from credentials
    @staticmethod
    @abc.abstractmethod
    def create_client():
        pass

    # External bucket URL
    @property
    @abc.abstractmethod
    def url(self) -> Union[str, None]:
        pass

    # Configure website for web storage buckets
    @abc.abstractmethod
    def setWebsite(self, mainPageSuffix, notFoundPage):
        pass

    # Remove all files from the bucket (using optional prefix)
    @abc.abstractmethod
    def deleteFiles(self, force, prefix):
        pass

    # Upload new file from path to bucket destination.
    @abc.abstractmethod
    def upload(self, path, destination, contentType, cacheControl):
        pass

    # Return storage file instance from bucket
    @abc.abstractmethod
    def file(self, destination) -> AbstractStorageFile:
        pass

    # Return all storage files (with optional prefix) instance from bucket
    @abc.abstractmethod
    def getFiles(self, prefix) -> list:
        pass



from .abstract_storage_plugin import AbstractStoragePlugin, AbstractStorageFile

from google.cloud import storage as gstorage
from google.cloud.storage.blob import Blob
from google.oauth2 import service_account

from typing import Union

# Simple wrapper around GoogleCloudStorage Blob class to provide
# generic "storage file" for this provider
class GoogleCloudStorageFile(AbstractStorageFile):
    def __init__(self, blob: Blob):
        self.blob = blob

    @property
    def name(self) -> str:
        return self.blob.name

    @property
    def metadata(self) -> dict:
        return self.blob.metadata

    @metadata.setter
    def metadata(self, metadata: dict):
        self.blob.metadata = metadata

    def exists(self) -> bool:
        return self.blob.exists()

    def delete(self) -> None:
        self.blob.delete()

    def save(self, data: Union[str, bytes], contentType: str) -> None:
        self.blob.upload_from_string(data=data, content_type=contentType)

    def download(self) -> bytes:
        return self.blob.download_as_bytes()

    def signed_url(self, version: str, action: str, expires: int, contentType: str) -> str:
        return self.blob.generate_signed_url(expiration=expires, version=version, method=action, response_type=contentType)

# Simple wrapper around GoogleCloudStorage bucket class to provide
# generic bucket storage service for this provider
class GoogleCloudStoragePlugin(AbstractStoragePlugin):
    def __init__(self, client, namespace, apiHost, web, credentials):
        super().__init__(client, namespace, apiHost, web, credentials)
        self.bucket = self.client.get_bucket(self.bucket_key)

    @staticmethod
    def id() -> str:
        return "@nimbella/storage-gcs"

    @staticmethod
    def prepare_creds(credentials: dict) -> service_account.Credentials:
        return service_account.Credentials.from_service_account_info(credentials)

    @staticmethod
    def create_client(credentials: service_account.Credentials) -> gstorage.Client:
        return gstorage.Client(credentials=credentials)

    @property
    def url(self) -> Union[str, None]:
        if self.web:
            return f'https://{self.bucket_key}'

    def file(self, destination) -> GoogleCloudStorageFile:
        return GoogleCloudStorageFile(self.bucket.blob(destination))

    def deleteFiles(self, prefix=None):
        blobs_to_delete = list(self.client.list_blobs(self.bucket, prefix=prefix))
        self.bucket.delete_blobs(blobs_to_delete)

    def upload(self, path, destination, contentType, cacheControl):
        blob = self.bucket.blob(destination)
        blob.cache_control = cacheControl
        with open(path, "rb") as f:
            blob.upload_from_file(file_obj=f, content_type=contentType)

    def setWebsite(self, mainPageSuffix = None, notFoundPage = None):
        self.bucket.configure_website(mainPageSuffix, notFoundPage)

    def getFiles(self, prefix = None) -> list:
        all_blobs = list(self.client.list_blobs(self.bucket, prefix=prefix))
        return list(map(lambda b: GoogleCloudStorageFile(b), all_blobs))

    @property
    def bucket_key(self):
        hostpart = '-'.join(self.apiHost.replace('https://', '').split('.'))
        datapart = '' if self.web else 'data-'
        return f'{datapart}{self.namespace}-{hostpart}'



from nimbella.storage import plugin_manager

import unittest

class TestPluginManager(unittest.TestCase):
    def test_finds_google_storage_plugin(self):
        id = "@nimbella/storage-gcs"
        plugin = plugin_manager.find_plugin(id)
        self.assertIsNotNone(plugin)
        self.assertEqual(plugin.id(), id)

    def test_finds_aws_storage_plugin(self):
        id = "@nimbella/storage-s3"
        plugin = plugin_manager.find_plugin(id)
        self.assertIsNotNone(plugin)
        self.assertEqual(plugin.id(), id)


    def test_does_not_find_missing_plugin(self):
        id = "@nimbella/storage-missing"
        plugin = plugin_manager.find_plugin(id)
        self.assertIsNone(plugin)



"""
/**
 * Copyright (c) 2020-present, Nimbella, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
"""

import os
import json

import redis as kv
from google.cloud import storage as gstorage
from google.oauth2 import service_account
from .storage import plugin_manager

def redis():
    redisIP = os.getenv('__NIM_REDIS_IP', "")
    redisPassword = os.getenv('__NIM_REDIS_PASSWORD', "")
    if len(redisIP) == 0:
        raise Exception('Key-Value store is not available.')
    elif len(redisPassword) == 0:
        raise Exception('Key-Value store credentials are not available.')
    else:
        return kv.Redis(host=redisIP, port=6379, password=redisPassword)


def storage(web=False):
    namespace = os.getenv('__OW_NAMESPACE', "")
    apiHost = os.getenv('__OW_API_HOST', "")
    creds = os.getenv('__NIM_STORAGE_KEY', "")

    if len(namespace) == 0 or len(apiHost) == 0:
        raise Exception(
            'Not enough information in the environment to determine the object store bucket name.')

    if len(creds) == 0:
        raise Exception('Object store credentials are not available.')
    try:
        creds = json.loads(creds)
    except:
        raise Exception(
            'Insufficient information in provided credentials or credentials were invalid.')

    provider_id = creds.get('provider', '@nimbella/storage-gcs')
    plugin = plugin_manager.find_plugin(provider_id)
    if plugin is None:
        raise Exception(f'Unable to find storage provider plugin with identifier: {provider_id}')

    provider_creds = plugin.prepare_creds(creds)
    provider_client = plugin.create_client(provider_creds)

    return plugin(provider_client, namespace, apiHost, web, creds)



#!/usr/bin/env python
"""
/**
 * Copyright (c) 2020-present, Nimbella, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
"""

from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = [line.strip() for line in f.readlines()]

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name='nimbella',
    version='2.0.0',
    author='Nimbella Corporation',
    author_email='info@nimbella.com',
    description='A python package to interact with Nimbella cloud services.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nimbella/nimbella-sdk-python",
    license='Apache-2.0',
    zip_safe=True,
    packages=find_packages(),
    install_requires=requirements,
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'License :: OSI Approved :: Apache Software License',
    ],
)
